==> open-xchange-realtime-core_7.2.1.orig.tar.bz2: open-xchange-realtime-core-7.2.1/com.openexchange.realtime.directory/src/com/openexchange/realtime/directory/Resource.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.realtime.directory;

import java.io.Serializable;
import java.util.Date;
import com.openexchange.realtime.packet.Presence;

/**
 * {@link Resource} - Combines Presence and RoutingInfo.
 * 
 * @author <a href="mailto:tobias.friedrich@open-xchange.com">Tobias Friedrich</a>
 */
public interface Resource extends Serializable {

    /**
     * Gets the presence information.
     * 
     * @return null or the associated Presence Stanza
     */
    Presence getPresence();

    /**
     * Sets the presence information
     * 
     * @param presence the Presence Stanza to set
     */
    void setPresence(Presence presence);

    /**
     * Gets internal routing information inside the server, e.g. to specify a node in a cluster member the resource is physically connected
     * to.
     * 
     * @return The routing information
     */
    Serializable getRoutingInfo();

    /**
     * Sets the routing information
     * 
     * @param routingInfo The routing information to set
     */
    void setRoutingInfo(Serializable routingInfo);

    /**
     * Gets the time the resource was last updated or created
     * 
     * @return The timestamp
     */
    Date getTimestamp();

    /**
     * Sets the timestamp
     * 
     * @param timestamp The timestamp to set
     */
    void setTimestamp(Date timestamp);

}

==> open-xchange-realtime-core_7.6.0.orig.tar.bz2: open-xchange-realtime-core-7.6.0/com.openexchange.realtime.directory/src/com/openexchange/realtime/directory/Resource.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2014 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.realtime.directory;

import java.io.Serializable;
import java.util.Date;
import com.openexchange.realtime.packet.Presence;

/**
 * {@link Resource} - Combines Presence and RoutingInfo.
 *
 * @author <a href="mailto:tobias.friedrich@open-xchange.com">Tobias Friedrich</a>
 */
public interface Resource extends Serializable {

    /**
     * Gets the presence information.
     *
     * @return null or the associated Presence Stanza
     */
    Presence getPresence();

    /**
     * Sets the presence information
     *
     * @param presence the Presence Stanza to set
     */
    void setPresence(Presence presence);

    /**
     * Gets internal routing information inside the server, e.g. to specify a node in a cluster member the resource is physically connected
     * to.
     *
     * @return The routing information
     */
    Object getRoutingInfo();

    /**
     * Sets the routing information
     *
     * @param routingInfo The routing information to set
     */
    void setRoutingInfo(Object routingInfo);

    /**
     * Gets the time the resource was last updated or created
     *
     * @return The timestamp
     */
    Date getTimestamp();

    /**
     * Sets the timestamp
     *
     * @param timestamp The timestamp to set
     */
    void setTimestamp(Date timestamp);

}
